Crate elrond_wasm_module_features

Crate elrond_wasm_module_features 

Modules

endpoints

Structs

AbiProvider
ContractObj
FeatureName

Constants

FEATURE_NOT_SET
FEATURE_OFF
FEATURE_ON

Traits

AutoImpl
EndpointWrappers
FeaturesModule
This is a standard smart contract module, that when added to a smart contract offers feature flag capabilities.
ProxyTrait

Functions

contract_obj